==> kleandisk-2.0beta2.tar.gz: kleandisk-2.0beta2/kleandisk/main.cpp <==
	/***************************************************************************
                          main.cpp  -  description
                             -------------------
    begin                : wo feb  7 09:47:42 CET 2001
    copyright            : (C) 2001 by Arjan Buursink
    email                : buursink@wanadoo.nl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <iostream.h>

#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <klocale.h>
#include <kmessagebox.h>
#include <kprocess.h>

#include "kleandisk.h"
#include "info.h"

static const char *description =
	I18N_NOOP("Kleandisk");
// INSERT A DESCRIPTION FOR YOUR APPLICATION HERE
	
	
static KCmdLineOptions options[] =
{
	{ "e", I18N_NOOP("Used to mark end of 'make install'"), 0 },
  { 0, 0, 0 }
  // INSERT YOUR COMMANDLINE OPTIONS HERE
};

int main(int argc, char *argv[])
{

  KAboutData aboutData( "kleandisk", I18N_NOOP("Kleandisk"),
    VERSION, description, KAboutData::License_GPL,
    "(c) 2001, Arjan Buursink");
  aboutData.addAuthor("Arjan Buursink",0, "buursink@wanadoo.nl");
  KCmdLineArgs::init( argc, argv, &aboutData );
  KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
  KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
  if (args -> isSet("e")){
		endInstall();
		exit(0);
	}
  KApplication a;
  Kleandisk *kleandisk = new Kleandisk();
  a.setMainWidget(kleandisk);
  kleandisk->show();  

  return a.exec();
}

void endInstall(){
	ABProcess proc("mv");
	proc << "mv";
	proc << insDir() + "tmp";
	proc << newInsBaseFileName() + ".files";
	proc.start(KProcess::Block, KProcess::AllOutput);
	if (proc.error().length() > 0)
		printf(i18n("'make install' is already marked ended\n"));
}

==> kleandisk-2.1beta2.tar.gz: kleandisk-2.1beta2/kleandisk/main.cpp <==
/***************************************************************************
                          main.cpp  -  description
                             -------------------
    begin                : wo feb  7 09:47:42 CET 2001
    copyright            : (C) 2001 by Arjan Buursink
    email                : buursink@wanadoo.nl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <klocale.h>
#include <kmessagebox.h>
#include <kprocess.h>

#include "kleandisk.h"
#include "info.h"

static const char *description =
	I18N_NOOP("Kleandisk");
// INSERT A DESCRIPTION FOR YOUR APPLICATION HERE
	
	
static KCmdLineOptions options[] =
{
	{ "e", I18N_NOOP("Used to mark end of 'make install'"), 0 },
  { 0, 0, 0 }
  // INSERT YOUR COMMANDLINE OPTIONS HERE
};

int main(int argc, char *argv[])
{
  KAboutData aboutData( "kleandisk", I18N_NOOP("Kleandisk"),
    VERSION, description, KAboutData::License_GPL,
    "(c) 2001, Arjan Buursink");
  aboutData.addAuthor("Arjan Buursink",0, "arjan.buursink@planet.nl");
  KCmdLineArgs::init( argc, argv, &aboutData );
  KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
  KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
  KApplication a;
  Kleandisk *kleandisk = new Kleandisk();
  a.setMainWidget(kleandisk);
  if (args -> isSet("e")){
		endInstall();
		exit(0);
	}
  kleandisk->show();
  return a.exec();
}

void endInstall(){
	ABProcess proc;
	proc << "mv";
	proc << insDir() + "tmp";
	proc << newInsBaseFileName() + ".files";
	proc.exec(true);
	if (proc.error())
		printf(i18n("'make install' is already marked ended\n"));
}
